@@ -1,4 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  *  gnome-print-paper-selector.c: A paper selector widget
  *
@@ -78,7 +78,7 @@ struct _GnomePaperSelector {
 	GPANode *paper_size_node;
 	GPANode *printer;
 	
-	guint handler_unit, handler_preview, handler_paper_size, handler_printer;
+	guint handler_unit, handler_paper_size, handler_printer;
 };
 
 struct _GnomePaperSelectorClass {
@@ -141,6 +141,12 @@ gnome_paper_selector_update_spin_limits (GnomePaperSelector *ps)
 	ps->m.l->upper = ps->pw - ps->mr; gpa_spinbutton_update (ps->m.l);
 }
 
+static GpaPaperPreviewItem *
+gps_get_preview (GnomePaperSelector *ps)
+{
+	return GPA_PAPER_PREVIEW_ITEM (GNOME_PAPER_PREVIEW (ps->preview)->item);
+}
+
 static void
 gps_psize_value_changed (GtkAdjustment *adj, GnomePaperSelector *ps)
 {
@@ -172,9 +178,7 @@ gps_m_size_value_changed (GtkAdjustment *adj, GnomePaperSelector *ps)
 	ps->mt = ps->m.t->value;
 	ps->mb = ps->m.b->value;
 
-	gpa_paper_preview_item_set_logical_margins 
-		(GPA_PAPER_PREVIEW_ITEM (GNOME_PAPER_PREVIEW 
-					 (ps->preview)->item),
+	gpa_paper_preview_item_set_logical_margins (gps_get_preview (ps),
 		 ps->ml, ps->mr, ps->mt, ps->mb);
 	gnome_paper_selector_update_spin_limits (ps);
 }
@@ -200,11 +204,6 @@ gnome_paper_selector_finalize (GObject *object)
 
 		node = G_OBJECT (gnome_print_config_get_node (ps->config));
 
-		if (ps->handler_preview) {
-			g_signal_handler_disconnect (node, ps->handler_preview);
-			ps->handler_preview = 0;
-		}
-
 		if (ps->handler_unit) {
 			g_signal_handler_disconnect (node, ps->handler_unit);
 			ps->handler_unit = 0;
@@ -235,8 +234,7 @@ lmargin_top_unit_activated (GtkSpinButton *spin_button,
 		GdkEventFocus *event,
 		GnomePaperSelector *ps)
 {
-	gpa_paper_preview_item_set_lm_highlights
-		(GPA_PAPER_PREVIEW_ITEM (GNOME_PAPER_PREVIEW (ps->preview)->item),
+	gpa_paper_preview_item_set_lm_highlights (gps_get_preview (ps),
 		 TRUE, FALSE, FALSE, FALSE);
 	return FALSE;
 }
@@ -246,8 +244,7 @@ lmargin_bottom_unit_activated (GtkSpinButton *spin_button,
 		GdkEventFocus *event,
 		GnomePaperSelector *ps)
 {
-	gpa_paper_preview_item_set_lm_highlights
-		(GPA_PAPER_PREVIEW_ITEM (GNOME_PAPER_PREVIEW (ps->preview)->item),
+	gpa_paper_preview_item_set_lm_highlights (gps_get_preview (ps),
 		 FALSE, TRUE, FALSE, FALSE);
 	return FALSE;
 }
@@ -257,8 +254,7 @@ lmargin_left_unit_activated (GtkSpinButton *spin_button,
 		GdkEventFocus *event,
 		GnomePaperSelector *ps)
 {
-	gpa_paper_preview_item_set_lm_highlights
-		(GPA_PAPER_PREVIEW_ITEM (GNOME_PAPER_PREVIEW (ps->preview)->item),
+	gpa_paper_preview_item_set_lm_highlights (gps_get_preview (ps),
 		 FALSE, FALSE, TRUE, FALSE);
 	return FALSE;
 }
@@ -268,8 +264,7 @@ lmargin_right_unit_activated (GtkSpinButton *spin_button,
 		GdkEventFocus *event,
 		GnomePaperSelector *ps)
 {
-	gpa_paper_preview_item_set_lm_highlights
-		(GPA_PAPER_PREVIEW_ITEM (GNOME_PAPER_PREVIEW (ps->preview)->item),
+	gpa_paper_preview_item_set_lm_highlights (gps_get_preview (ps),
 		 FALSE, FALSE, FALSE, TRUE);
 	return FALSE;
 }
@@ -279,8 +274,7 @@ lmargin_unit_deactivated (GtkSpinButton *spin_button,
 		  GdkEventFocus *event,
 		  GnomePaperSelector *ps)
 {
-	gpa_paper_preview_item_set_lm_highlights
-		(GPA_PAPER_PREVIEW_ITEM (GNOME_PAPER_PREVIEW (ps->preview)->item),
+	gpa_paper_preview_item_set_lm_highlights (gps_get_preview (ps),
 		 FALSE, FALSE, FALSE, FALSE);
 	return FALSE;
 }
